# coding: utf-8

# flake8: noqa
"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from abcdef_sdk.models.get_gifs_by_id200_response import GetGifsById200Response
from abcdef_sdk.models.gif import Gif
from abcdef_sdk.models.gif_images import GifImages
from abcdef_sdk.models.gif_images_downsized import GifImagesDownsized
from abcdef_sdk.models.gif_images_downsized_large import GifImagesDownsizedLarge
from abcdef_sdk.models.gif_images_downsized_medium import GifImagesDownsizedMedium
from abcdef_sdk.models.gif_images_downsized_small import GifImagesDownsizedSmall
from abcdef_sdk.models.gif_images_downsized_still import GifImagesDownsizedStill
from abcdef_sdk.models.gif_images_fixed_height import GifImagesFixedHeight
from abcdef_sdk.models.gif_images_fixed_height_downsampled import GifImagesFixedHeightDownsampled
from abcdef_sdk.models.gif_images_fixed_height_small import GifImagesFixedHeightSmall
from abcdef_sdk.models.gif_images_fixed_height_small_still import GifImagesFixedHeightSmallStill
from abcdef_sdk.models.gif_images_fixed_height_still import GifImagesFixedHeightStill
from abcdef_sdk.models.gif_images_fixed_width import GifImagesFixedWidth
from abcdef_sdk.models.gif_images_fixed_width_downsampled import GifImagesFixedWidthDownsampled
from abcdef_sdk.models.gif_images_fixed_width_small import GifImagesFixedWidthSmall
from abcdef_sdk.models.gif_images_fixed_width_small_still import GifImagesFixedWidthSmallStill
from abcdef_sdk.models.gif_images_fixed_width_still import GifImagesFixedWidthStill
from abcdef_sdk.models.gif_images_looping import GifImagesLooping
from abcdef_sdk.models.gif_images_original import GifImagesOriginal
from abcdef_sdk.models.gif_images_original_still import GifImagesOriginalStill
from abcdef_sdk.models.gif_images_preview import GifImagesPreview
from abcdef_sdk.models.gif_images_preview_gif import GifImagesPreviewGif
from abcdef_sdk.models.image import Image
from abcdef_sdk.models.meta import Meta
from abcdef_sdk.models.pagination import Pagination
from abcdef_sdk.models.random_gif200_response import RandomGif200Response
from abcdef_sdk.models.user import User



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from abcdef_sdk.models.gif import Gif

class TestGif(unittest.TestCase):
    """Gif unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Gif:
        """Test Gif
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Gif`
        """
        model = Gif()
        if include_optional:
            return Gif(
                bitly_url = 'http://gph.is/1gsWDcL',
                content_url = '',
                create_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                embded_url = 'http://giphy.com/embed/YsTs5ltWtEhnq',
                featured_tags = [
                    ''
                    ],
                id = 'YsTs5ltWtEhnq',
                images = abcdef_sdk.models.gif_images.Gif_images(
                    downsized = null, 
                    downsized_large = null, 
                    downsized_medium = null, 
                    downsized_small = null, 
                    downsized_still = null, 
                    fixed_height = null, 
                    fixed_height_downsampled = null, 
                    fixed_height_small = null, 
                    fixed_height_small_still = null, 
                    fixed_height_still = null, 
                    fixed_width = null, 
                    fixed_width_downsampled = null, 
                    fixed_width_small = null, 
                    fixed_width_small_still = null, 
                    fixed_width_still = null, 
                    looping = null, 
                    original = null, 
                    original_still = null, 
                    preview = null, 
                    preview_gif = null, ),
                import_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                rating = 'g',
                slug = 'confused-flying-YsTs5ltWtEhnq',
                source = 'http://www.reddit.com/r/reactiongifs/comments/1xpyaa/superman_goes_to_hollywood/',
                source_post_url = 'http://cheezburger.com/5282328320',
                source_tld = 'cheezburger.com',
                tags = [
                    ''
                    ],
                type = 'gif',
                update_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url = 'http://giphy.com/gifs/confused-flying-YsTs5ltWtEhnq',
                user = abcdef_sdk.models.user.User(
                    avatar_url = 'https://media1.giphy.com/avatars/election2016/XwYrZi5H87o6.gif', 
                    banner_url = 'https://media4.giphy.com/avatars/cheezburger/XkuejOhoGLE6.jpg', 
                    display_name = 'JoeCool4000', 
                    profile_url = 'https://giphy.com/cheezburger/', 
                    twitter = '@joecool4000', 
                    username = 'joecool4000', ),
                username = 'JoeCool4000'
            )
        else:
            return Gif(
        )
        """

    def testGif(self):
        """Test Gif"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from abcdef_sdk.models.random_gif200_response import RandomGif200Response

class TestRandomGif200Response(unittest.TestCase):
    """RandomGif200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RandomGif200Response:
        """Test RandomGif200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RandomGif200Response`
        """
        model = RandomGif200Response()
        if include_optional:
            return RandomGif200Response(
                data = abcdef_sdk.models.gif.Gif(
                    bitly_url = 'http://gph.is/1gsWDcL', 
                    content_url = '', 
                    create_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    embded_url = 'http://giphy.com/embed/YsTs5ltWtEhnq', 
                    featured_tags = [
                        ''
                        ], 
                    id = 'YsTs5ltWtEhnq', 
                    images = abcdef_sdk.models.gif_images.Gif_images(
                        downsized = null, 
                        downsized_large = null, 
                        downsized_medium = null, 
                        downsized_small = null, 
                        downsized_still = null, 
                        fixed_height = null, 
                        fixed_height_downsampled = null, 
                        fixed_height_small = null, 
                        fixed_height_small_still = null, 
                        fixed_height_still = null, 
                        fixed_width = null, 
                        fixed_width_downsampled = null, 
                        fixed_width_small = null, 
                        fixed_width_small_still = null, 
                        fixed_width_still = null, 
                        looping = null, 
                        original = null, 
                        original_still = null, 
                        preview = null, 
                        preview_gif = null, ), 
                    import_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    rating = 'g', 
                    slug = 'confused-flying-YsTs5ltWtEhnq', 
                    source = 'http://www.reddit.com/r/reactiongifs/comments/1xpyaa/superman_goes_to_hollywood/', 
                    source_post_url = 'http://cheezburger.com/5282328320', 
                    source_tld = 'cheezburger.com', 
                    tags = [
                        ''
                        ], 
                    type = 'gif', 
                    update_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = 'http://giphy.com/gifs/confused-flying-YsTs5ltWtEhnq', 
                    user = abcdef_sdk.models.user.User(
                        avatar_url = 'https://media1.giphy.com/avatars/election2016/XwYrZi5H87o6.gif', 
                        banner_url = 'https://media4.giphy.com/avatars/cheezburger/XkuejOhoGLE6.jpg', 
                        display_name = 'JoeCool4000', 
                        profile_url = 'https://giphy.com/cheezburger/', 
                        twitter = '@joecool4000', 
                        username = 'joecool4000', ), 
                    username = 'JoeCool4000', ),
                meta = abcdef_sdk.models.meta.Meta(
                    msg = 'OK', 
                    response_id = '57eea03c72381f86e05c35d2', 
                    status = 200, )
            )
        else:
            return RandomGif200Response(
        )
        """

    def testRandomGif200Response(self):
        """Test RandomGif200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Giphy API

    Giphy API

    The version of the OpenAPI document: 1.0
    Contact: support@giphy.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from abcdef_sdk.models.user import User

class TestUser(unittest.TestCase):
    """User unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> User:
        """Test User
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `User`
        """
        model = User()
        if include_optional:
            return User(
                avatar_url = 'https://media1.giphy.com/avatars/election2016/XwYrZi5H87o6.gif',
                banner_url = 'https://media4.giphy.com/avatars/cheezburger/XkuejOhoGLE6.jpg',
                display_name = 'JoeCool4000',
                profile_url = 'https://giphy.com/cheezburger/',
                twitter = '@joecool4000',
                username = 'joecool4000'
            )
        else:
            return User(
        )
        """

    def testUser(self):
        """Test User"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
